@@ -1,7 +1,7 @@
 /*
     Qalculate (library)
 
-    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna_k@fmgirl.com)
+    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,6 +13,7 @@
 #define FUNCTION_H
 
 #include <libqalculate/ExpressionItem.h>
+#include <libqalculate/Number.h>
 #include <libqalculate/includes.h>
 
 /** @file */
@@ -79,6 +80,7 @@ class MathFunction : public ExpressionItem {
 	virtual MathStructure createFunctionMathStructureFromVArgs(const MathStructure &vargs);
 	virtual MathStructure createFunctionMathStructureFromSVArgs(vector<string> &svargs);	
 	string scondition;
+	string sexample;
 	
   public:
   
@@ -95,6 +97,9 @@ class MathFunction : public ExpressionItem {
 	* @returns ::FunctionSubtype.
 	*/
 	virtual int subtype() const;
+	
+	string example(bool raw_format = false, string name_string = "") const;
+	void setExample(string new_example);
 
 	bool testArgumentCount(int itmp);
 	virtual MathStructure calculate(const string &eq, const EvaluationOptions &eo = default_evaluation_options);
@@ -188,6 +193,7 @@ class MathFunction : public ExpressionItem {
 	virtual bool representsInteger(const MathStructure&, bool = false) const;
 	virtual bool representsNumber(const MathStructure&, bool = false) const;
 	virtual bool representsRational(const MathStructure&, bool = false) const;
+	virtual bool representsNonComplex(const MathStructure&, bool = false) const;
 	virtual bool representsReal(const MathStructure&, bool = false) const;
 	virtual bool representsComplex(const MathStructure&, bool = false) const;
 	virtual bool representsNonZero(const MathStructure&, bool = false) const;
@@ -196,6 +202,7 @@ class MathFunction : public ExpressionItem {
 	virtual bool representsUndefined(const MathStructure&) const;
 	virtual bool representsBoolean(const MathStructure&) const;
 	virtual bool representsNonMatrix(const MathStructure&) const;
+	virtual bool representsScalar(const MathStructure&) const;
 	
 };
 
@@ -479,6 +486,7 @@ class IntegerArgument : public Argument {
   protected:
   
 	Number *imin, *imax;
+	IntegerType i_inttype;
 
   protected:
   
@@ -486,19 +494,22 @@ class IntegerArgument : public Argument {
 	virtual string subprintlong() const;
 
   public:
-  
-  	IntegerArgument(string name_ = "", ArgumentMinMaxPreDefinition minmax = ARGUMENT_MIN_MAX_NONE, bool does_test = true, bool does_error = true);
+
+	IntegerArgument(string name_ = "", ArgumentMinMaxPreDefinition minmax = ARGUMENT_MIN_MAX_NONE, bool does_test = true, bool does_error = true, IntegerType integer_type = INTEGER_TYPE_NONE);
 	IntegerArgument(const IntegerArgument *arg);
 	virtual ~IntegerArgument();
 
+	IntegerType integerType() const;
+	void setIntegerType(IntegerType integer_type);
+
 	virtual void set(const Argument *arg);
 	virtual Argument *copy() const;
 
-	virtual string print() const;	
+	virtual string print() const;
 
-	void setMin(const Number *nmin);	
+	void setMin(const Number *nmin);
 	const Number *min() const;
-	void setMax(const Number *nmax);	
+	void setMax(const Number *nmax);
 	const Number *max() const;
 	
 	virtual int type() const;
@@ -561,6 +572,7 @@ class DateArgument : public Argument {
   	DateArgument(string name_ = "", bool does_test = true, bool does_error = true);
 	DateArgument(const DateArgument *arg);
 	virtual ~DateArgument();
+	virtual void parse(MathStructure *mstruct, const string &str, const ParseOptions &po = default_parse_options) const;
 	virtual int type() const;
 	virtual Argument *copy() const;
 	virtual string print() const;
